@@ -1,14 +1,14 @@
 --
 --  url_rev.sql
 --
---  $Id: url_rew.sql,v 1.35.2.14 2012/03/08 10:46:19 source Exp $
+--  $Id$
 --
 --  URL rewrite rules for ODS
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -168,6 +168,25 @@ create procedure DB.DBA.ODS_PHOTO_ITEM_PAGE (in par varchar, in fmt varchar, in
 }
 ;
 
+create procedure DB.DBA.ODS_MAIL_ITEM_PAGE (in par varchar, in fmt varchar, in val varchar)
+{
+  declare ret, ufname any;
+
+  if (par = 'ufname')
+    {
+      connection_set ('ufname', val);
+      ret := '';
+    }
+  else if (par = 'post')
+    {
+      ufname := connection_get ('ufname');
+      ret := (select TOP 1 WAI_ID from DB.DBA.WA_INSTANCE, DB.DBA.WA_MEMBER, DB.DBA.SYS_USERS where U_NAME = ufname and U_ID = WAM_USER and WAM_APP_TYPE = 'oMail' and WAM_MEMBER_TYPE = 1 and WAI_NAME = WAM_INST);
+      ret := sprintf ('%d/open.vsp?op=%s,1', ret, val);
+    }
+  return sprintf (fmt, ret);
+}
+;
+
 create procedure DB.DBA.ODS_PHOTO_GEMS_PAGE (in par varchar, in fmt varchar, in val varchar)
 {
 
@@ -187,6 +206,19 @@ create procedure DB.DBA.ODS_PHOTO_GEMS_PAGE (in par varchar, in fmt varchar, in
 }
 ;
 
+create procedure DB.DBA.ODS_FOLDER_PAGE (in par varchar, in fmt varchar, in val varchar)
+{
+  declare ret any;
+  if (par = 'item')
+    {
+      ret := DB.DBA.DAV_SEARCH_PATH (atoi (val), 'C');
+      if (isinteger (ret))
+        ret := '';
+    }
+  return sprintf (fmt, ret);
+}
+;
+
 create procedure DB.DBA.ODS_DET_REF (in par varchar, in fmt varchar, in val varchar)
 {
   declare iri, res any;
@@ -255,6 +287,17 @@ create procedure DB.DBA.ODS_URLREW_XRDS (in path varchar)
 }
 ;
 
+create procedure DB.DBA.ODS_SERVICES_PAGE (in par varchar, in fmt varchar, in val varchar)
+{
+  declare ret any;
+
+  if (par = 'part')
+    {
+      ret := sprintf ('http://%s%s/services/%s', SIOC..get_cname (), SIOC..get_base_path (), val);
+    }
+  return sprintf (fmt, ret);
+}
+;
 
 -- Person IRI as HTML
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_person_html', 1,
@@ -405,8 +448,8 @@ DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_item_html', 1,
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_item_briefcase_html', 1,
     '/dataspace/doc/([^/]*)/(briefcase)/([^/]*)/folder/([^/\\?]*)',
     vector('uname', 'app', 'inst', 'item'), 3,
-    '%s?id=%s&what=c', vector('inst', 'item'),
-    'DB.DBA.ODS_ITEM_PAGE',
+    '%s', vector('item'),
+    'DB.DBA.ODS_FOLDER_PAGE',
     NULL,
     2);
 
@@ -516,6 +559,15 @@ DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_discussion_item_html', 1,
     NULL,
     2);
 
+-- A discussion item page
+DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_mail_item_html', 1,
+    '/dataspace/([^/]*)/mail/([\\d]+)',
+    vector ('ufname', 'post'), 2,
+    '/oMail/%s%s', vector('ufname', 'post'),
+    'DB.DBA.ODS_MAIL_ITEM_PAGE',
+    NULL,
+    2);
+
 DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_blog_tag', 1,
     '/dataspace/([^/]*)/weblog/([^/]*)/tag/([^/\\?]*)',
     vector('uname', 'inst', 'tag'), 3,
@@ -659,7 +711,7 @@ create procedure DB.DBA.ODS_URLREW_HDR (in in_path varchar)
     {
       tmp := path;
     }
-  links := 'Link: ';
+  links := sprintf ('X-RDF-Graph: http://%{WSHost}s/dataspace\r\nX-SPARQL-Endpoint: http://%{WSHost}s/sparql-auth/\r\nLink: ');
   links := links || sprintf ('<http://%s%s>; rel="http://xmlns.com/foaf/0.1/primaryTopic",', host, tmp);
   links := links || sprintf ('\r\n <http://%s%s>; rev="describedby",', host, tmp);
   if (uname is not null)
@@ -754,10 +806,20 @@ DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_error', 1,
     null,
     2);
 
+DB.DBA.URLREWRITE_CREATE_REGEX_RULE ('ods_services', 1,
+    '/dataspace/doc/services/([^\\?]*)\x24',
+    vector('part'), 1,
+    '/describe/?url=%U', vector('part'),
+    'DB.DBA.ODS_SERVICES_PAGE',
+    null,
+    2,
+    302);
+
 -- All rules are processed in the order below.
 -- Every rule will be tried and last matching rule will win
 DB.DBA.URLREWRITE_CREATE_RULELIST ('ods_rule_list1', 1,
    	vector(
+	  'ods_services',
 	  'ods_person_html',
 	  'ods_person_yadis',
 	  'ods_apps_html',
@@ -791,6 +853,7 @@ DB.DBA.URLREWRITE_CREATE_RULELIST ('ods_rule_list1', 1,
 	  'ods_apps_gems_html',
 	  'ods_apps_tags_html',
 	  'ods_discussion_item_html',
+	  'ods_mail_item_html',
 	  'ods_blog_tag',
 	  'ods_main',
 	  'ods_space_html',
