@@ -2,7 +2,7 @@
 #  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 #  project.
 #
-#  Copyright (C) 1998-2007 OpenLink Software
+#  Copyright (C) 1998-2013 OpenLink Software
 #
 #  This project is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the
@@ -31,13 +31,13 @@ def login_form()
     <div id="lf" class="form">
       #{display_error()}
       <div class="header">
-        User login
+        Please identify yourself
       </div>
       <ul id="lf_tabs" class="tabs">
-        <li id="lf_tab_0" title="ODS">ODS</li>
+        <li id="lf_tab_0" title="Digest">Digest</li>
         <li id="lf_tab_1" title="OpenID">OpenID</li>
         <li id="lf_tab_2" title="Facebook" style="display: none;">Facebook</li>
-        <li id="lf_tab_3" title="FOAF+SSL" style="display: none;">FOAF+SSL</li>
+        <li id="lf_tab_3" title="WebID" style="display: none;">WebID</li>
       </ul>
       <div style="min-height: 120px; border: 1px solid #aaa; margin: -13px 5px 5px 5px;">
         <div id="lf_content"></div>
@@ -45,7 +45,7 @@ def login_form()
       <table class="form" cellspacing="5">
         <tr>
           <th width="30%">
-            <label for="lf_uid">Member ID</label>
+                <label for="lf_uid">User ID</label>
           </th>
           <td nowrap="nowrap">
             <input type="text" name="lf_uid" value="" id="lf_uid" />
@@ -137,8 +137,8 @@ def user_form()
           </div>
         </div>
         <script type="text/javascript">
-          OAT.MSG.attach(OAT, OAT.MSG.OAT_LOAD, function (){selectProfile();});
-          OAT.MSG.attach(OAT, OAT.MSG.OAT_LOAD, function (){cRDF.open("<?V xpath_eval ('string (/user/iri)', vXml) ?>");});
+          OAT.MSG.attach(OAT, "PAGE_LOADED", function (){selectProfile();});
+          OAT.MSG.attach(OAT, "PAGE_LOADED", function (){cRDF.open("<?V xpath_eval ('string (/user/iri)', vXml) ?>");});
         </script>
       </div>
       <div class="footer">
@@ -964,14 +964,18 @@ def main()
     <link rel="stylesheet" type="text/css" href="/ods/rdfm.css" />
     <script type="text/javascript" src="/ods/users/js/users.js"></script>
     <script type="text/javascript" src="/ods/common.js"></script>
+    <script type="text/javascript" src="/ods/typeahead.js"></script>
+    <script type="text/javascript" src="/ods/tbl.js"></script>
+    <script type="text/javascript" src="/ods/validate.js"></script>
     <script type="text/javascript">
       // OAT
       var toolkitPath="/ods/oat";
-      var featureList = ["dom", "ajax2", "ws", "json", "tab", "dimmer", "combolist", "calendar", "crypto", "rdfmini", "dimmer", "grid", "graphsvg", "tagcloud", "anchor", "dock", "map", "timeline"];
+      var featureList = ["ajax", "json", "tab", "combolist", "calendar", "crypto", "rdfmini", "grid", "graphsvg", "tagcloud", "map", "timeline", "anchor"];
     </script>
     <script type="text/javascript" src="/ods/oat/loader.js"></script>
     <script type="text/javascript">
-      OAT.MSG.attach(OAT, OAT.MSG.OAT_LOAD, myInit);
+      OAT.MSG.attach(OAT, "PAGE_LOADED", myInit);
+      window.onload = function(){OAT.MSG.send(OAT, 'PAGE_LOADED');};
     </script>
   </head>
   <body>
@@ -1008,7 +1012,7 @@ def main()
       <div id="FT_R">
         <a href="/ods/faq.html">FAQ</a> | <a href="/ods/privacy.html">Privacy</a> | <a href="/ods/rabuse.vspx">Report Abuse</a>
         <div>
-          Copyright &copy; 1999-2010 OpenLink Software
+          Copyright &copy; 1999-2013 OpenLink Software
         </div>
       </div>
      </div>
