@@ -1,10 +1,10 @@
 /*
- *  $Id: facet.js,v 1.1.2.26 2012/03/05 17:38:05 source Exp $
+ *  $Id$
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
  *
- *  Copyright (C) 1998-2012 OpenLink Software
+ *  Copyright (C) 1998-2013 OpenLink Software
  *
  *  This project is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -292,7 +292,7 @@ function prop_val_dt_sel_init () {
 		if (v_h != '' && v_h.match (/\".*\"\^\^\<.*\>/) === null) {
                     if ($v('cond_dt') == '' || $v('cond_dt') == 'http://www.openlinksw.com/schemas/facets/dtp/plainstring')
 			v_h = '"'+ v_h +'"';
-  		    else
+                    else
   			v_h = '"' + v_h + '"^^<' + $v('cond_dt') + '>';
 		}
 		if (v_l != '' && v_l.match (/\".*\"\^\^\<.*\>/) === null) {
@@ -683,6 +683,7 @@ function handle_val_anchor_click (e) {
 	    $('cond_lo').value = val;
 	break;
     case "in":
+    case "not_in":
 	OAT.Event.prevent(e);
         in_ui.add_val (val, dtp, lang);
         break;
@@ -813,6 +814,7 @@ function fct_init_ui ()
 		OAT.Dom.show ('cond_dt');
 		break;
             case "in":
+	    case "not_in":
                 OAT.Dom.hide ('cond_inp_ctr');
                 OAT.Dom.hide ('cond_hi_ctr');
                 in_ui.show();
@@ -824,6 +826,9 @@ function fct_init_ui ()
                 geo_ui.show(); */
 	    }
         });
+	OAT.Event.attach('agg_type', 'change', function (e) {
+	  $('agg_form').submit();
+	});
     }
 }
 
