@@ -93,26 +93,16 @@ else
   myrm=rm
 fi
 
+
 version_init()
 {
-  if [ $VOS -eq 1 ]
-  then
-      if [ -f vad_version ]
-      then
-      VERSION=`cat vad_version`
-      else
-        LOG "The vad_version does not exist, please verify your checkout"
-    exit 1
-      fi
-  else
-      rm -f version.tmp
-      for i in `find . -name 'Entries' | grep -v "vad/"`; do
-      cat $i | grep "^[^D].*" | cut -f 3 -d "/" | sed -e "s/1\.//g" >> version.tmp
-      done
-      VERSION=`cat version.tmp | awk ' BEGIN { cnt=9 } { cnt = cnt + $1 } END { printf "1.%02.02f", cnt/100 }'`
-      rm -f version.tmp
-      echo "$VERSION" > vad_version
-  fi
+    if [ -f vad_version ]
+    then
+	VERSION=`cat vad_version`
+    else
+	LOG "The vad_version does not exist, please verify your checkout"
+	exit 1
+    fi
 }
 
 do_command_safe () {
@@ -192,7 +182,7 @@ directory_init() {
   # components which are not in their place
   cp -Rf $HOME/binsrc/oat vad/vsp/fct
   cp -Rf $HOME/binsrc/samples/dbpedia/vsp/statics vad/vsp/fct/rdfdesc
-  cp -Rf $HOME/binsrc/rdf_mappers/virt_rdf_label.sql vad/vsp/fct
+  #cp -Rf $HOME/binsrc/rdf_mappers/virt_rdf_label.sql vad/vsp/fct
   cp -Rf styles vad/vsp/fct/rdfdesc
   cp -Rf s vad/vsp/fct/rdfdesc
 
