@@ -1,10 +1,10 @@
 --  
---  $Id: msdtc_conn_check.sql,v 1.2.2.1 2012/03/08 12:55:07 source Exp $
+--  $Id$
 --  
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --  
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --  
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -27,5 +27,5 @@
 -- ECHO BOTH ": mts_connect() : STATE=" $STATE "\n";
 
 select mts_status ('MTS');
-echo both $if $equ $last[1] 'connected' "PASSED" "*** FAILED";
-echo both ": server " $last[1] " to MS DTC\n";
+ECHO BOTH $IF $EQU $LAST[1] 'connected' "PASSED" "***FAILED";
+ECHO BOTH ": server " $LAST[1] " to MS DTC\n";
