@@ -1,10 +1,10 @@
 --  
---  $Id: nwxmltype3a.sql,v 1.2.2.1 2012/03/08 12:55:07 source Exp $
+--  $Id$
 --  
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --  
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --  
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -85,8 +85,8 @@ create procedure fill_xtf_3()
 fill_xtf_1_2();
 
 select count(*) from XML_TEXT_FRAGS where cast(XTF_FRAG1 as varchar) <> cast(XTF_FRAG2 as varchar);
-echo both $if $equ $last[1] 0 "PASSED" "*** FAILED";
-echo both ": " $last[1] " XMLType instances were cropped with errors\n";
+ECHO BOTH $IF $EQU $LAST[1] 0 "PASSED" "***FAILED";
+ECHO BOTH ": " $LAST[1] " XMLType instances were cropped with errors\n";
 
 insert into LONG_XML_TEXTS (LXML_NAME, LXML_DOC) values ('/Doc'	, '<a/>');
 insert into LONG_XML_TEXTS (LXML_NAME, LXML_DOC) values ('/Doc/cha1'	, '<a/>');
@@ -101,11 +101,11 @@ checkpoint;
 fill_xtf_3();
 
 select count(*) from XML_TEXT_FRAGS where cast(XTF_FRAG1 as varchar) <> cast(XTF_FRAG2 as varchar);
-echo both $if $equ $last[1] 0 "PASSED" "*** FAILED";
-echo both ": " $last[1] " explicitly cropped XMLType instances were filled with errors\n";
+ECHO BOTH $IF $EQU $LAST[1] 0 "PASSED" "***FAILED";
+ECHO BOTH ": " $LAST[1] " explicitly cropped XMLType instances were filled with errors\n";
 select count(*) from XML_TEXT_FRAGS where cast(XTF_FRAG1 as varchar) <> cast(XTF_FRAG3 as varchar);
-echo both $if $equ $last[1] 0 "PASSED" "*** FAILED";
-echo both ": " $last[1] " implicitly cropped XMLType instances were filled with errors\n";
+ECHO BOTH $IF $EQU $LAST[1] 0 "PASSED" "***FAILED";
+ECHO BOTH ": " $LAST[1] " implicitly cropped XMLType instances were filled with errors\n";
 
 update LONG_XML_TEXTS set LXML_DOC = '<?xml version="1.0"?>
 <!DOCTYPE book [
@@ -146,5 +146,5 @@ where LXML_NAME = '/Doc/sub22';
 select LXML_NAME, FRAG from LONG_XML_TEXTS where xpath_contains (LXML_DOC, '//*', FRAG);
 select count (FRAG) from LONG_XML_TEXTS where xpath_contains (LXML_DOC, '//*', FRAG);
 -- There was an bug here: must be 19 frags, not 11 or 15.
-echo both $if $equ $last[1] 19 "PASSED" "*** FAILED";
-echo both ": " $last[1] " fragments in XMLType column before log replay\n";
+ECHO BOTH $IF $EQU $LAST[1] 19 "PASSED" "***FAILED";
+ECHO BOTH ": " $LAST[1] " fragments in XMLType column before log replay\n";
