@@ -1,10 +1,10 @@
 --
---  $Id: obackup_userck.sql,v 1.3.2.4 2012/03/08 12:55:07 source Exp $
+--  $Id$
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -52,11 +52,13 @@ succ:
 ;
 
 SELECT CHECK_UNAUTH_BACKUP_SEC();
-ECHO BOTH "Invoking BACKUP_ONLINE procedure from unauthtorized user test is " $LAST[1] "\n";
+ECHO BOTH $LAST[1];
+ECHO BOTH ": Invoking BACKUP_ONLINE procedure from unauthtorized user test\n";
 
 RECONNECT dba;
 SELECT CHECK_AUTH_BACKUP_SEC();
-ECHO BOTH "Invoking BACKUP_ONLINE procedure from authtorized user test is " $LAST[1] "\n";
+ECHO BOTH $LAST[1];
+ECHO BOTH ": Invoking BACKUP_ONLINE procedure from authtorized user test\n";
 
 
 ADD USER GROUP IMPOSTER "DBA";
@@ -65,7 +67,8 @@ ADD USER GROUP IMPOSTER "DBA";
 RECONNECT "IMPOSTER";
 
 SELECT CHECK_AUTH_BACKUP_SEC();
-ECHO BOTH "Invoking BACKUP_ONLINE procedure from authtorized user test is " $LAST[1] "\n";
+ECHO BOTH $LAST[1];
+ECHO BOTH ": Invoking BACKUP_ONLINE procedure from authtorized user test\n";
 
 BACKUP_ONLINE ('/usr/aaa_#', 150, 200);
 ECHO BOTH $IF $EQU $STATE 42000 "PASSED" "***FAILED";
@@ -131,5 +134,3 @@ create_seqs ('bx', 10000);
 create_seqs ('x', 10000);
 
 backup_online ('vvv', 150);
-
-
