@@ -1,14 +1,14 @@
 --
 --  rtesta.sql
 --
---  $Id: rtesta.sql,v 1.2.2.3 2012/03/08 12:55:08 source Exp $
+--  $Id$
 --
 --  Remote database testing
 --  
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --  
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --  
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -140,8 +140,8 @@ from r1..t1 a,
 where b.row_no = f(a.row_no) and c.row_no = f (b.row_no) and c.row_no = f(b.row_no) and d.row_no = f(c.row_no)
 option (order);
 
-echo both $if $equ $last[2] 2398000 "PASSED" "***FAILED";
-echo both ": sum of row_no in 4 way dt, hash,loop join of r1..t1.\n";
+ECHO BOTH $IF $EQU $LAST[2] 2398000 "PASSED" "***FAILED";
+ECHO BOTH ": sum of row_no in 4 way dt, hash,loop join of r1..t1.\n";
 
 select count (*)  from (select * from r1..t1 union select * from r1..t1) f where row_no < (select max (row_no) from t1) - 2900;
 ECHO BOTH $IF $EQU $LAST[1] 999 "PASSED" "***FAILED";
@@ -161,5 +161,5 @@ ECHO BOTH $IF $EQU $LAST[1] 1000 "PASSED" "***FAILED";
 ECHO BOTH ": count " $LAST[1] " count union r1..t1, r1..t1\n";
 
 select top 10 a.row_no, b.row_no from r1..t1 a, (select top 1 row_no from r1..t1) b where b.row_no between f (a.row_no - 1) and f (a.row_no + 1) option (order, loop);
-echo both $if $equ $rowcnt 3 "PASSED" "***FAILED";
-echo both ": arrayed subq with top\n";
+ECHO BOTH $IF $EQU $ROWCNT 3 "PASSED" "***FAILED";
+ECHO BOTH ": arrayed subq with top\n";
