@@ -1,10 +1,10 @@
 --  
---  $Id: tsoap.sql,v 1.2.2.2 2012/03/08 12:55:09 source Exp $
+--  $Id$
 --  
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --  
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --  
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -385,6 +385,9 @@ create procedure DB.DBA.SOAPTEST ()
 ECHO BOTH $IF $EQU $STATE OK "PASSED" "*** FAILED";
 ECHO BOTH ": creating VSP SOAP server procedure STATE=" $STATE " MESSAGE=" $MESSAGE "\n";
 
+create user SOAP_SRV;
+grant execute on DB.DBA.SOAPTEST to SOAP_SRV;
+
 soap_call ('localhost:$U{HTTPPORT}', '/vspsoap.vsp', 'fake', 'test', vector(), 11);
 ECHO BOTH $IF $EQU $STATE OK "PASSED" "*** FAILED";
 ECHO BOTH ": calling the VSP SOAP server with fake#test STATE=" $STATE " MESSAGE=" $MESSAGE "\n";
@@ -403,6 +406,8 @@ create module DB.DBA.SOAPMOD {
   procedure SOAPMOD3() { return 14; };
 };
 
+GRANT EXECUTE ON DB.DBA.SOAPMOD TO SOAP_SRV;
+
 select xml_tree_doc (soap_sdl ('DB.DBA.SOAPMOD', 'URL'));
 ECHO BOTH $IF $EQU $STATE OK "PASSED" "*** FAILED";
 ECHO BOTH ": SDL for a module valid STATE=" $STATE " MESSAGE=" $MESSAGE "\n";
