@@ -1,14 +1,14 @@
 --
 --  vfs.sql
 --
---  $Id: vfs.sql,v 1.10.2.29 2012/03/08 12:55:20 source Exp $
+--  $Id$
 --
 --  Site-copy robot.
 --  
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --  
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --  
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -2129,7 +2129,7 @@ create procedure WS.WS.SITEMAP_RDF_STORE (in _host varchar, in _url varchar, in
     }
   if (url_ck like '%.rdf' or _c_type = 'application/rdf+xml')
     {
-      DB.DBA.RDF_LOAD_RDFXML (_content, base, graph, 3);
+      DB.DBA.RDF_LOAD_RDFXML (_content, base, graph, 0, 3);
     }
   else if (url_ck like '%.n3' or url_ck like '%.ttl' or url_ck like '%.nt' or _c_type = 'text/n3' or _c_type = 'text/rdf+n3')
     {
