@@ -1,14 +1,14 @@
 /*
  *  search.c
  *
- *  $Id: search.c,v 1.35.2.36 2012/03/08 12:55:35 source Exp $
+ *  $Id$
  *
  *  Search
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
  *
- *  Copyright (C) 1998-2012 OpenLink Software
+ *  Copyright (C) 1998-2013 OpenLink Software
  *
  *  This project is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -331,6 +331,9 @@ it_cursor_t *
 dbg_itc_create (const char *file, int line, void * isp, lock_trx_t * trx)
 {
   it_cursor_t * itc = (it_cursor_t*) DBG_NAME (dk_alloc_box) (DBG_ARGS sizeof (it_cursor_t), DV_ITC);
+#ifdef VALGRIND
+  memset (itc, 0, sizeof (it_cursor_t));
+#endif
   ITC_INIT (itc, isp, trx);
   itc->itc_type = ITC_CURSOR;
   itc->itc_is_allocated = 1;
@@ -341,6 +344,9 @@ it_cursor_t *
 itc_create (void * isp, lock_trx_t * trx)
 {
   it_cursor_t * itc = (it_cursor_t*)dk_alloc_box (sizeof (it_cursor_t), DV_ITC);
+#ifdef VALGRIND
+  memset (itc, 0, sizeof (it_cursor_t));
+#endif
   ITC_INIT (itc, isp, trx);
   itc->itc_type = ITC_CURSOR;
   itc->itc_is_allocated = 1;
@@ -993,9 +999,9 @@ itc_like_compare (it_cursor_t * itc, buffer_desc_t * buf, caddr_t pattern, searc
   char temp[MAX_ROW_BYTES];
   int res, st = LIKE_ARG_CHAR, pt = LIKE_ARG_CHAR;
   dtp_t dtp2 = DV_TYPE_OF (pattern), dtp1;
-  row_size_t len1, len3;
-  unsigned short offset;
-  db_buf_t dv1, dv3;
+  row_size_t len1 = 0, len3 = 0;
+  unsigned short offset = 0;
+  db_buf_t dv1 = NULL, dv3 = NULL;
   collation_t *collation = spec->sp_collation;
   dbe_col_loc_t * cl = &spec->sp_cl;
   ROW_STR_COL (itc->itc_insert_key, buf, itc->itc_row_data, cl, dv1, len1, dv3, len3, offset);
