@@ -1,12 +1,12 @@
 --
---  $Id: snapshot_repl.sql,v 1.3.2.2 2012/03/08 12:55:35 source Exp $
+--  $Id$
 --
 --  SNP replication support
 --
 --  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
 --  project.
 --
---  Copyright (C) 1998-2012 OpenLink Software
+--  Copyright (C) 1998-2013 OpenLink Software
 --
 --  This project is free software; you can redistribute it and/or modify it
 --  under the terms of the GNU General Public License as published by the
@@ -81,27 +81,6 @@ create procedure REPL_OFFSET_TIME (
 }
 ;
 
-
-
-create procedure REPL_FQNAME (in _tbl varchar)
-{
-  declare _parts any;
-  _parts := vector ('', '', '');
-  declare _ix, _len integer;
-  _ix := 0;
-  _len := length (_parts);
-  while (_ix < _len)
-    {
-      declare _p any;
-      _p := name_part (_tbl, _ix);
-      if (_p <> 0)
-        _parts[_ix] := sprintf ('"%I"', _p);
-      _ix := _ix + 1;
-    }
-  return concat (_parts[0], '.', _parts[1], '.', _parts[2]);
-}
-;
-
 create procedure REPL_ORIGIN (in _rowguid varchar)
 {
   declare _delim_pos integer;
@@ -238,64 +217,6 @@ create index SYS_REPL_POSTPONED_LOCKED_COL_ID on DB.DBA.SYS_REPL_POSTPONED_RES (
 create index SYS_REPL_POSTPONED_LOCKED_RES_ID on DB.DBA.SYS_REPL_POSTPONED_RES (LOCKED_RES_ID)
 ;
 
-create procedure REPL_COLTYPE_PS (
-    in _coltype varchar,
-    in _col_dtp integer, in _col_prec integer, in _col_scale integer)
-  returns varchar
-{
-  if ((_col_dtp = 181 or _col_dtp = 182 or _col_dtp = 192 or
-       _col_dtp = 222 or _col_dtp = 225)
-      and _col_prec is not null and _col_prec <> 0)
-    {
-      -- (length) for char or varchar
-      declare _pos integer;
-      declare _len_spec varchar;
-      _pos := strstr (_coltype, '()');
-      _len_spec := sprintf ('(%d)', _col_prec);
-      if (_pos is null)
-        _coltype := concat (_coltype, _len_spec);
-      else
-        {
-          declare _prefix, _suffix varchar;
-          _prefix := subseq (_coltype, 0, _pos);
-          _suffix := subseq (_coltype, _pos + 2);
-          _coltype := concat (_prefix, _len_spec, _suffix);
-        }
-    }
-  else if (_col_dtp = 219)
-    {
-      -- (prec, scale) for numeric
-      if (_col_prec < _col_scale)
-        _col_scale := 0;
-      _coltype := concat (_coltype, sprintf('(%d, %d)', _col_prec, _col_scale));
-    }
-  return _coltype;
-}
-;
-
-create procedure REPL_COLTYPE (in _col any) returns varchar
-{
-  declare _col_dtp, _col_prec, _col_scale integer;
-  _col_dtp := aref (_col, 1);
-  _col_scale := aref (_col, 2);
-  _col_prec := aref (_col, 3);
-
-  if (_col_dtp = 219)
-    {
-      if (_col_scale > 15)
-	_col_scale := 15;
-      if (_col_prec > 40)
-	_col_prec := 40;
-    }
-  return REPL_COLTYPE_PS (
-      dv_type_title(_col_dtp), _col_dtp, _col_prec, _col_scale);
-}
-;
-
-
-
-
-
 create procedure REPL_REMOTE_TYPES_RAW (in _dsn varchar)
   returns any
 {
@@ -395,49 +316,6 @@ create procedure REPL_REMOTE_TYPES (
 }
 ;
 
-
-create procedure REPL_PK_COLS (in _tbl varchar)
-{
-  declare cr_pk cursor for
-      select
-          sc."COLUMN",
-          sc."COL_DTP",
-	  sc."COL_SCALE",
-	  sc."COL_PREC"
-      from
-          DB.DBA.SYS_KEYS k,
-	  DB.DBA.SYS_KEY_PARTS kp, DB.DBA.SYS_COLS sc
-      where
-          upper(k.KEY_TABLE) = upper(_tbl) and
-	  __any_grants(k.KEY_TABLE) and
-	  k.KEY_IS_MAIN = 1 and
-	  k.KEY_MIGRATE_TO is NULL and
-	  kp.KP_KEY_ID = k.KEY_ID and
-	  kp.KP_NTH < k.KEY_DECL_PARTS and
-	  sc.COL_ID = kp.KP_COL
-          and sc."COLUMN" <> '_IDN'
-      order by
-          kp.KP_NTH;
-  declare _pk_cols any;
-  declare _col_name varchar;
-  declare _col_dtp, _col_scale, _col_prec integer;
-
-  _pk_cols := vector ();
-  open cr_pk;
-  whenever not found goto done;
-  while (1)
-    {
-      fetch cr_pk into _col_name, _col_dtp, _col_scale, _col_prec;
-      _col_name := repl_undot_name (_col_name);
-      _pk_cols := vector_concat (
-          _pk_cols, vector (vector (_col_name, _col_dtp, _col_scale, _col_prec)));
-    }
-done:
-  close cr_pk;
-  return _pk_cols;
-}
-;
-
 create procedure REPL_ALL_COLS (in _tbl varchar)
 {
   declare _stmt varchar;
