@@ -1,12 +1,12 @@
 /*
- *  $Id: sqlinx.c,v 1.1.2.8 2012/03/08 12:55:36 source Exp $
+ *  $Id$
  *
  *  Index selection
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
  *
- *  Copyright (C) 1998-2012 OpenLink Software
+ *  Copyright (C) 1998-2013 OpenLink Software
  *
  *  This project is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -750,10 +750,7 @@ sqlo_index_path (sqlo_t * so, df_elt_t * tb_dfe, dk_set_t path, int pk_given)
       index_choice_t ic;
       if (opt_inx_name && !path)
 	{
-	  if (!strcmp (opt_inx_name, "PRIMARY KEY")
-	      && key->key_is_primary)
-	    ;
-	  else if (CASEMODESTRCMP (opt_inx_name, key->key_name))
+	  if (!key_matches_index_opt (key, opt_inx_name))
 	    continue;
 	}
       if (pk_given && !key->key_is_primary)
