@@ -1,14 +1,14 @@
 /*
  *  sqlrun.c
  *
- *  $Id: sqlrun.c,v 1.24.2.13 2010/02/01 12:53:46 source Exp $
+ *  $Id$
  *
  *  SQL query execution
  *
  *  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
  *  project.
  *
- *  Copyright (C) 1998-2006 OpenLink Software
+ *  Copyright (C) 1998-2013 OpenLink Software
  *
  *  This project is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -282,6 +282,8 @@ sel_out_free (state_slot_t ** out_slots, caddr_t * qst)
   DO_BOX (state_slot_t *, sl, inx, out_slots)
   {
     char sl_type = sl->ssl_type;
+    if (sl->ssl_is_alias)
+      goto next;
     if ((sl_type == SSL_PLACEHOLDER || sl_type == SSL_ITC))
       {
 	placeholder_t *pl = (placeholder_t *) qst[inx];
@@ -289,10 +291,6 @@ sel_out_free (state_slot_t ** out_slots, caddr_t * qst)
 	  plh_free (pl);
 	continue;
       }
-    if (sl->ssl_is_alias)
-      goto next;
-
-
     dt = qst[inx];
     if (dt)
       {
@@ -658,7 +656,7 @@ cli_terminate_in_itc_fail (client_connection_t * cli, it_cursor_t * itc, buffer_
       lt->lt_status = LT_BLOWN_OFF;
       if (itc)
 	itc_bust_this_trx (itc, buf, ITC_BUST_THROW);
-      sqlr_new_error ("S1T00", "{CLI..", "Client cancelled or disconnected");
+      sqlr_new_error ("S1T00", "CLI..", "Client cancelled or disconnected");
     }
 }
 
@@ -901,53 +899,54 @@ ks_search_param_cast (it_cursor_t * itc, search_spec_t * sp, caddr_t data)
   if (dtp == target_dtp)
     {
       ITC_COPY_PARAM (itc, data);
+      return KS_CAST_OK;
     }
-  else
+  switch (target_dtp)
     {
-      if (IS_BLOB_DTP (target_dtp))
+    case DV_BLOB: case DV_BLOB_BIN: case DV_BLOB_WIDE: case DV_BLOB_XPER:
+      if (dtp != DV_DB_NULL)
 	{
 	  char* cl_name = __get_column_name (sp->sp_cl.cl_col_id,
 	      itc->itc_insert_key ? itc->itc_insert_key : itc->itc_row_key);
-	  if (dtp != DV_DB_NULL)
 	    sqlr_new_error ("22023", "SR347",
 		"The long varchar, long varbinary and long nvarchar "
 		"data types cannot be used in the WHERE, HAVING, or ON clause, "
 		"except with the IS NULL predicate for column '%s'", cl_name);
 	}
-
-      if (IS_NUM_DTP (dtp) && IS_NUM_DTP (target_dtp))
-	{
+      break;
 	  /* compare different number types.  If col more precise than arg, cast to col here, otherwise the cast is in itc_col_check.
 	  * if param is more precise, disable any inlined compare funcs since they do not cast. */
-	  switch (target_dtp)
-	    {
 	    case DV_LONG_INT:
+      if (!IS_NUM_DTP (dtp))
+        break;
 	      ITC_COPY_PARAM (itc, data); /* all are more precise, no cast down */
 	      itc->itc_key_spec.ksp_key_cmp = NULL;
-	      return 0;
+      return KS_CAST_OK;
 	    case DV_SINGLE_FLOAT:
-	      if (DV_LONG_INT == dtp)
-		goto cast_param_up;
+      if ((DV_LONG_INT == dtp) || !IS_NUM_DTP (dtp))
+        break;
 	      ITC_COPY_PARAM (itc, data);
 	      itc->itc_key_spec.ksp_key_cmp = NULL;
-	      return 0;
+      return KS_CAST_OK;
 	    case DV_DOUBLE_FLOAT:
-	      goto cast_param_up;
+      break;
 	    case DV_NUMERIC:
-	      if (DV_DOUBLE_FLOAT == dtp)
-		{
+      if (DV_DOUBLE_FLOAT != dtp)
+        break;
 		  ITC_COPY_PARAM (itc, data);
 		  itc->itc_key_spec.ksp_key_cmp = NULL;
-		  return 0;
-		}
-	      goto cast_param_up;
-	    }
-	  return 0;
+      return KS_CAST_OK;
+/* same is for dates/datetime pair */
+    case DV_DATE:
+      if (DV_DATETIME != dtp)
+        break;
+      ITC_COPY_PARAM (itc, data);
+      itc->itc_key_spec.ksp_key_cmp = NULL;
+      return KS_CAST_OK;
 	}
-    cast_param_up:
       data = box_cast_to (itc->itc_out_state, data, dtp, target_dtp,
 			  sp->sp_cl.cl_sqt.sqt_precision, sp->sp_cl.cl_sqt.sqt_scale, &err);
-      if (err)
+      if (err || (DV_DB_NULL == DV_TYPE_OF (data)))
 	{
 	  query_instance_t * qi = (query_instance_t *) itc->itc_out_state;
 	  if (qi->qi_no_cast_error)
@@ -959,15 +958,16 @@ ks_search_param_cast (it_cursor_t * itc, search_spec_t * sp, caddr_t data)
 		dtp = DV_LONG_INT;
 	      if (IS_NUM_DTP (target_dtp))
 		target_dtp = DV_LONG_INT;
+              if (DV_DB_NULL == DV_TYPE_OF (data))
+                dk_free_box (data);
 	      return (dtp < target_dtp ? KS_CAST_DTP_LT : KS_CAST_DTP_GT);
 	    }
 	  else
 	    sqlr_resignal (err);
 	}
-
       ITC_SEARCH_PARAM (itc, data);
       ITC_OWNS_PARAM (itc, data);
-    }
+
   return KS_CAST_OK;
 }
 
@@ -1489,6 +1489,12 @@ table_source_input (table_source_t * ts, caddr_t * inst,
 	{
 	  if (order_buf)
 	    GPF_T;		/* TS loops back and order buf is set */
+	  if (!order_itc->itc_is_registered)
+	    {
+	      log_error ("cursor not continuable as it is unregistered");
+	      SRC_IN_STATE (ts, inst) = NULL;
+	      return;
+	    }
 	  ITC_FAIL (order_itc)
 	  {
 	    order_buf = page_reenter_excl (order_itc);
@@ -1556,6 +1562,11 @@ table_source_input (table_source_t * ts, caddr_t * inst,
 	  || code_vec_run (ts->src_gen.src_after_test, state))
 	{
 	  any_passed = 1;
+#ifndef NDEBUG
+	  /* if in state itc must be registered */
+	  if (SRC_IN_STATE (ts, inst) != NULL && !order_itc->itc_is_registered)
+	    GPF_T;
+#endif
 	  qn_ts_send_output ((data_source_t *) ts, state, ts->ts_after_join_test);
 	}
       state = NULL;
@@ -1809,7 +1820,7 @@ delete_node_run (delete_node_t * del, caddr_t * inst, caddr_t * state)
 	{
 	  itc_page_leave (cr_itc, cr_buf);
 	  itc_free (cr_itc);
-	  sqlr_new_error ("42000", "SR...", "Position of single key delete is notr on the right key");
+	  sqlr_new_error ("42000", "SR...", "Position of single key delete is not on the right key");
 	}
 
       page_row_bm (cr_buf, cr_itc->itc_map_pos, &rd, RO_ROW, cr_itc);
@@ -2215,11 +2226,8 @@ qi_alloc (query_t * qr, stmt_options_t * opts, caddr_t * auto_qi,
   int len = qr->qr_instance_length;
   if (qr->qr_select_node)
     {
-      if (opts)
-	{
-	  if (opts->so_prefetch > 0)
+      if (opts && opts->so_prefetch > 0)
 	    len += (int) (opts->so_prefetch * sizeof (caddr_t));
-	}
       else
 	len += SELECT_PREFETCH_QUOTA * sizeof (caddr_t);
     }
@@ -2342,7 +2350,7 @@ select_node_input (select_node_t * sel, caddr_t * inst, caddr_t * state)
 	    cli_send_row_count (qi->qi_client, 0, NULL, THREAD_CURRENT_THREAD);
 	}
     }
-  if (!sel->sel_set_no && !sel_top_count (sel, inst))
+  if (!sel_top_count (sel, inst))
     return;
   if (qi->qi_caller == CALLER_CLIENT)
     {
@@ -2384,8 +2392,6 @@ select_node_input (select_node_t * sel, caddr_t * inst, caddr_t * state)
 	}
       box[fill++] = out_copy;
       inst[sel->sel_out_fill] = (caddr_t) (ptrlong) fill;
-      if (sel->sel_set_no)
-	sel_top_count (sel, inst);
     }
   else
     {
@@ -2398,8 +2404,6 @@ select_node_input (select_node_t * sel, caddr_t * inst, caddr_t * state)
 	}
       box[fill++] = out_copy;
       inst[sel->sel_out_fill] = (caddr_t) (ptrlong) fill;
-      if (sel->sel_set_no)
-	sel_top_count (sel, inst);
     }
 
   if (quota != PREFETCH_ALL
@@ -2706,7 +2710,9 @@ qn_anytime_state (data_source_t * qn, caddr_t * inst)
 		  caddr_t err = subq_handle_reset (qi, reset_code);
 		  POP_QR_RESET;
 		  if (err_is_anytime (err))
-		    at_printf (("subq %d interrupted by anytime", qn->src_in_state));
+		    {
+		      at_printf (("subq %d interrupted by anytime", qn->src_in_state));
+		    }
 		  if (0 && err_is_anytime (err))
 		    SRC_IN_STATE (qn, inst) = NULL; /* timed out when continuing.  No more tries for this subq **/
 		  sqlr_resignal (err);
@@ -3007,6 +3013,9 @@ qi_initial_enter_trx (query_instance_t * qi)
   return rc;
 }
 
+#define QI_SERIALIZABLE(qi,qr) \
+  if ((qi)->qi_no_cast_error && PL_EXCLUSIVE == (qr)->qr_lock_mode && !(qi)->qi_autocommit && !(qi)->qi_non_txn_insert) \
+    (qi)->qi_isolation = ISO_SERIALIZABLE
 
 caddr_t
 qr_exec (client_connection_t * cli, query_t * qr,
@@ -3067,7 +3076,7 @@ qr_exec (client_connection_t * cli, query_t * qr,
       qi->qi_no_triggers = caller->qi_no_triggers;
     }
   was_autocommit = qi->qi_autocommit;
-
+  QI_SERIALIZABLE (qi, qr);
   if (stmt)
     {
       is_timeout = qi_initial_enter_trx (qi);
@@ -3290,7 +3299,7 @@ qr_dml_array_exec (client_connection_t * cli, query_t * qr,
   else
     GPF_T1 ("array exec only from client");
   was_autocommit = qi->qi_autocommit;
-
+  QI_SERIALIZABLE (qi, qr);
   if (stmt)
     {
       is_timeout = qi_initial_enter_trx (qi);
@@ -3410,9 +3419,12 @@ qr_dml_array_exec (client_connection_t * cli, query_t * qr,
       return err;
     }
   dk_free_box (detail);
-  for (inx = 0; inx < param_inx - 1; inx++)
-    cli_send_row_count (cli, 0, NULL, self_thread);
-  cli_send_row_count (cli, n_affected, NULL, self_thread);
+  if (CALLER_LOCAL != caller)
+    {
+      for (inx = 0; inx < param_inx - 1; inx++)
+	cli_send_row_count (cli, 0, NULL, self_thread);
+      cli_send_row_count (cli, n_affected, NULL, self_thread);
+    }
 #ifdef WIRE_DEBUG
   list_wired_buffers (__FILE__, __LINE__, "qr_exec finish");
 #endif
@@ -3495,7 +3507,7 @@ qr_subq_exec (client_connection_t * cli, query_t * qr,
   qi->qi_no_triggers = caller->qi_no_triggers;
   qi->qi_isolation = caller->qi_isolation;
   qi->qi_lock_mode = caller->qi_lock_mode;
-
+  QI_SERIALIZABLE (qi, qr);
   if (lc)
     {
       memset (lc, 0, sizeof (local_cursor_t));
