@@ -1,9 +1,10 @@
-/* A Bison parser, made by GNU Bison 2.4.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton interface for Bison's Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2009, 2010 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -68,26 +69,28 @@
      _AT_prefix_L = 285,
      _AT_this_L = 286,
      _MINUS_INF_L = 287,
-     INF_L = 288,
-     NaN_L = 289,
-     false_L = 290,
-     true_L = 291,
-     __TTL_PUNCT_END = 292,
-     __TTL_NONPUNCT_START = 293,
-     TURTLE_INTEGER = 294,
-     TURTLE_DECIMAL = 295,
-     TURTLE_DOUBLE = 296,
-     TURTLE_STRING = 297,
-     KEYWORD = 298,
-     LANGTAG = 299,
-     QNAME = 300,
-     QNAME_NS = 301,
-     VARIABLE = 302,
-     BLANK_NODE_LABEL = 303,
-     Q_IRI_REF = 304,
-     _GARBAGE_BEFORE_DOT_WS = 305,
-     TTL_RECOVERABLE_ERROR = 306,
-     __TTL_NONPUNCT_END = 307
+     BASE_L = 288,
+     INF_L = 289,
+     NaN_L = 290,
+     PREFIX_L = 291,
+     false_L = 292,
+     true_L = 293,
+     __TTL_PUNCT_END = 294,
+     __TTL_NONPUNCT_START = 295,
+     TURTLE_INTEGER = 296,
+     TURTLE_DECIMAL = 297,
+     TURTLE_DOUBLE = 298,
+     TURTLE_STRING = 299,
+     KEYWORD = 300,
+     LANGTAG = 301,
+     QNAME = 302,
+     QNAME_NS = 303,
+     VARIABLE = 304,
+     BLANK_NODE_LABEL = 305,
+     Q_IRI_REF = 306,
+     _GARBAGE_BEFORE_DOT_WS = 307,
+     TTL_RECOVERABLE_ERROR = 308,
+     __TTL_NONPUNCT_END = 309
    };
 #endif
 /* Tokens.  */
@@ -121,26 +124,28 @@
 #define _AT_prefix_L 285
 #define _AT_this_L 286
 #define _MINUS_INF_L 287
-#define INF_L 288
-#define NaN_L 289
-#define false_L 290
-#define true_L 291
-#define __TTL_PUNCT_END 292
-#define __TTL_NONPUNCT_START 293
-#define TURTLE_INTEGER 294
-#define TURTLE_DECIMAL 295
-#define TURTLE_DOUBLE 296
-#define TURTLE_STRING 297
-#define KEYWORD 298
-#define LANGTAG 299
-#define QNAME 300
-#define QNAME_NS 301
-#define VARIABLE 302
-#define BLANK_NODE_LABEL 303
-#define Q_IRI_REF 304
-#define _GARBAGE_BEFORE_DOT_WS 305
-#define TTL_RECOVERABLE_ERROR 306
-#define __TTL_NONPUNCT_END 307
+#define BASE_L 288
+#define INF_L 289
+#define NaN_L 290
+#define PREFIX_L 291
+#define false_L 292
+#define true_L 293
+#define __TTL_PUNCT_END 294
+#define __TTL_NONPUNCT_START 295
+#define TURTLE_INTEGER 296
+#define TURTLE_DECIMAL 297
+#define TURTLE_DOUBLE 298
+#define TURTLE_STRING 299
+#define KEYWORD 300
+#define LANGTAG 301
+#define QNAME 302
+#define QNAME_NS 303
+#define VARIABLE 304
+#define BLANK_NODE_LABEL 305
+#define Q_IRI_REF 306
+#define _GARBAGE_BEFORE_DOT_WS 307
+#define TTL_RECOVERABLE_ERROR 308
+#define __TTL_NONPUNCT_END 309
 
 
 
@@ -149,8 +154,8 @@
 typedef union YYSTYPE
 {
 
-/* Line 1685 of yacc.c  */
-#line 72 "./turtle_p.y"
+/* Line 1676 of yacc.c  */
+#line 73 "./turtle_p.y"
 
   caddr_t box;
   ptrlong token_type;
@@ -159,8 +164,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 1685 of yacc.c  */
-#line 164 "turtle_p.h"
+/* Line 1676 of yacc.c  */
+#line 169 "turtle_p.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
